@@ -14,24 +14,28 @@
 """Grok components"""
 
 from zope.security.permission import Permission
+from grokcore.security.interfaces import HAVE_ROLE
+
 
 class Permission(Permission):
     pass
 
 Public = 'zope.Public'
 
-from zope.securitypolicy.role import Role as securitypolicy_Role
 
-class Role(securitypolicy_Role):
-    """Base class for roles in Grok applications.
+if HAVE_ROLE:
+    from zope.securitypolicy.role import Role as securitypolicy_Role
 
-    A role is a description of a class of users that gives them a
-    machine-readable name, a human-readable title, and a set of
-    permissions which users belong to that role should possess::
+    class Role(securitypolicy_Role):
+        """Base class for roles in Grok applications.
 
-        class Editor(grok.Role):
-            grok.name('news.Editor')
-            grok.title('Editor')
-            grok.permissions('news.EditArticle', 'news.PublishArticle')
+        A role is a description of a class of users that gives them a
+        machine-readable name, a human-readable title, and a set of
+        permissions which users belong to that role should possess::
 
-    """
\ No newline at end of file
+            class Editor(grok.Role):
+                grok.name('news.Editor')
+                grok.title('Editor')
+                grok.permissions('news.EditArticle', 'news.PublishArticle')
+
+        """
