@@ -28,9 +28,10 @@ class RequireDirectiveStore(StoreMultipleTimes):
         if (permissions is default) or not permissions:
             return default
         if len(permissions) > 1:
-            raise GrokError('grok.require was called multiple times in '
-                            '%r. It may only be set once for a class.'
-                            % component, component)
+            raise GrokError(
+                'grok.require was called multiple times in '
+                '%r. It may only be set once for a class.'
+                % component, component)
         return permissions[0]
 
     def pop(self, locals_, directive):
@@ -62,3 +63,40 @@ class require(martian.Directive):
         permission = self.store.pop(frame.f_locals, self)
         self.set(func, [permission])
         return func
+
+class permissions(martian.Directive):
+    """The `grokcore.security.permissions()` directive.
+
+    This directive is used inside of a `grok.Role` subclass to list the
+    permissions which each member of the role should always possess.
+    Note that permissions should be passed as strings, and that several
+    permissions they can simply be supplied as multiple arguments; there
+    is no need to place them inside of a tuple or list::
+
+        class MyRole(grokcore.security.Role):
+            grokcore.security.permissions('page.CreatePage', 'page.EditPage')
+            ...
+
+    """
+    scope = martian.CLASS
+    store = martian.ONCE
+    default = []
+
+    def validate(self, *values):
+        for value in values:
+            if martian.util.check_subclass(value, components.Permission):
+                continue
+            if martian.util.not_unicode_or_ascii(value):
+                raise GrokImportError(
+                    "You can only pass unicode values, ASCII values, or "
+                    "subclasses of grok.Permission to the '%s' directive."
+                    % self.name)
+
+    def factory(self, *values):
+        permission_ids = []
+        for value in values:
+            if martian.util.check_subclass(value, components.Permission):
+                permission_ids.append(grokcore.component.name.bind().get(value))
+            else:
+                permission_ids.append(value)
+        return permission_ids
