@@ -10,9 +10,10 @@ checker = renormalizing.RENormalizing([
     # str(Exception) has changed from Python 2.4 to 2.5 (due to
     # Exception now being a new-style class).  This changes the way
     # exceptions appear in traceback printouts.
-    (re.compile(r"ConfigurationExecutionError: <class '([\w.]+)'>:"),
-                r'ConfigurationExecutionError: \1:'),
-    ])
+    (re.compile(
+        r"ConfigurationExecutionError: <class '([\w.]+)'>:"),
+        r'ConfigurationExecutionError: \1:'),
+        ])
 
 def suiteFromPackage(name):
     files = resource_listdir(__name__, name)
@@ -24,20 +25,23 @@ def suiteFromPackage(name):
             continue
         if filename == '__init__.py':
             continue
-
         dottedname = 'grokcore.security.tests.%s.%s' % (name, filename[:-3])
-        test = doctest.DocTestSuite(dottedname,
-                                    tearDown=cleanUpZope,
-                                    checker=checker,
-                                    optionflags=doctest.ELLIPSIS+
-                                    doctest.NORMALIZE_WHITESPACE)
-
+        test = doctest.DocTestSuite(
+            dottedname,
+            tearDown=cleanUpZope,
+            checker=checker,
+            optionflags=doctest.ELLIPSIS+
+            doctest.NORMALIZE_WHITESPACE)
         suite.addTest(test)
     return suite
 
 def test_suite():
     suite = unittest.TestSuite()
-    for name in ['security']:
+    for name in [
+        'permissions',
+        'role',
+        'security',
+        ]:
         suite.addTest(suiteFromPackage(name))
     return suite
 
